#!/bin/sh -l
set -e

CERT_PATH="${CERT_PATH:-/home/dokku/.local/share/certs/cert.pem}"
PRIVKEY_PATH="${PRIVKEY_PATH:-/home/dokku/.local/share/certs/privkey.pem}"

if [ -z "$APP_NAME" ]; then
  echo "Error: APP_NAME is not set. Ensure the script is executed in the dokku/ci-docker-image environment." >&2
  exit 1
fi

if [ -z "$SSH_REMOTE" ]; then
  echo "Error: SSH_REMOTE is not set. Ensure the script is executed in the dokku/ci-docker-image environment." >&2
  exit 1
fi

dokku_cert_add() {
  echo "⚙ Assigning certs at $CERT_PATH and $PRIVKEY_PATH to $APP_NAME ..."
  ssh "$SSH_REMOTE" -- certs:add "$APP_NAME" "$CERT_PATH" "$PRIVKEY_PATH" || echo "Failed to assign certs" >&2
}

dokku_map_port_to_https() {
  port="$1"
  echo "⚙ Mapping $APP_NAME container port $port to HTTPS ..."
  ssh "$SSH_REMOTE" -- ports:add "$APP_NAME" "https:443:$port" || echo "Failed to map container port $port to HTTPS" >&2
}

dokku_cert_add
dokku_map_port_to_https 9966

echo "✅ Post-deployment configuration completed"
